==> monodevelop_2.0+dfsg.orig.tar.gz: monodevelop-2.0/src/core/Mono.Debugging/Mono.Debugging.Backend/IDebuggerSessionFrontend.cs <==
// IDebuggerSession.cs
//
// Author:
//   Lluis Sanchez Gual <lluis@novell.com>
//
// Copyright (c) 2008 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.
//
//

using System;
using Mono.Debugging.Client;

namespace Mono.Debugging.Backend
{
	public interface IDebuggerSessionFrontend
	{
		void NotifyTargetEvent (TargetEventArgs args);
		void NotifyTargetOutput (bool isStderr, string line);
		void NotifyDebuggerOutput (bool isStderr, string line);
		bool NotifyCustomBreakpointAction (string actionId, object handle);
		
		// To be called when the process is ready to run.
		void NotifyStarted ();
	}
}

==> monodevelop_2.4+dfsg.orig.tar.gz: monodevelop-2.4/src/core/Mono.Debugging/Mono.Debugging.Backend/IDebuggerSessionFrontend.cs <==
// IDebuggerSession.cs
//
// Author:
//   Lluis Sanchez Gual <lluis@novell.com>
//
// Copyright (c) 2008 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.
//
//

using System;
using Mono.Debugging.Client;

namespace Mono.Debugging.Backend
{
	public interface IDebuggerSessionFrontend
	{
		void NotifyTargetEvent (TargetEventArgs args);
		void NotifyTargetOutput (bool isStderr, string line);
		void NotifyDebuggerOutput (bool isStderr, string line);
		bool NotifyCustomBreakpointAction (string actionId, object handle);
		void NotifySourceFileLoaded (string fullFilePath);
		void NotifySourceFileUnloaded (string fullFilePath);
		
		// To be called when the process is ready to run.
		void NotifyStarted ();
	}
}
